@@ -1,10 +1,11 @@
 readSiteFlags  <- function(Directory, filename= "site_flags.txt") {
   
   X <- read.delim(file.path(Directory,filename, fsep =.Platform$file.sep), 
-                  skip = 44,                    
+                  comment.char = "%",                    
                   header = FALSE,                 
                   stringsAsFactors= FALSE)
-  flagNames <- paste("Flag",seq(1,12),sep ="_")
+  
+  flagNames <- paste("Flag",seq(from = 1,to=(ncol(X) -1)),sep ="_")
   colnames(X)<- c("Id",flagNames)
     
   return(X)
