@@ -1,7 +1,7 @@
 readSiteSummary <- function(Directory, filename= "site_summary.txt") {
   
   X <- read.delim(file.path(Directory,filename, fsep =.Platform$file.sep), 
-                  skip = 60,  
+                  comment.char = "%",  
                   na.strings = "-999.00",
                   header = FALSE,                 
                   stringsAsFactors= FALSE)
